@@ -204,6 +204,8 @@ class LeapLoader(LeapLoaderBase):
         preprocess_result = self._preprocess_result()
         result_payloads: List[DatasetTestResultPayload] = []
         dataset_base_handlers: List[Union[DatasetBaseHandler, MetadataHandler]] = self._get_all_dataset_base_handlers()
+        assert sum(isinstance(x, MetadataHandler) for x in dataset_base_handlers) < 100, "Metadata handles must be less than 100"
+        metadata_length = 0
         for dataset_base_handler in dataset_base_handlers:
             test_result = [DatasetTestResultPayload(dataset_base_handler.name)]
             for state, preprocess_response in preprocess_result.items():
@@ -218,9 +220,10 @@ class LeapLoader(LeapLoaderBase):
                     test_result[0].display[
                         state_name] = f"{repr(e)} in file {file_name}, line_number:  {line_number}\nStacktrace:\n{stacktrace}"
                     test_result[0].is_passed = False
-
+            if isinstance(dataset_base_handler, MetadataHandler):
+                metadata_length += len(test_result)
+                assert metadata_length < 800, "Total number of metadata columns handles must be less than 800"
             result_payloads.extend(test_result)
-
         return result_payloads
 
     @staticmethod
@@ -462,7 +465,7 @@ class LeapLoader(LeapLoaderBase):
 
         try:
             is_none = False
-            if value is None:
+            if value is None or (isinstance(value, (int, float, np.integer, np.floating)) and not np.isfinite(value)):
                 raise ValueError()
             converted_value = metadata_type_to_python_type[metadata_name_to_type[metadata_name]](value)
         except ValueError:
